phil_columns v3.1.0 Mix.PhilColumns

Link to this section Summary

Functions

Ensures the given repository's seeds path exists on the file system.

Restarts the app if there was any migration command.

Gets the seeds path from a repository.

Link to this section Functions

Link to this function

ensure_seeds_path(repo, opts)
ensure_seeds_path(Ecto.Repo.t(), Keyword.t()) :: String.t()

Ensures the given repository's seeds path exists on the file system.

Link to this function

restart_apps_if_migrated(apps, list)
restart_apps_if_migrated([atom()], list()) :: :ok

Restarts the app if there was any migration command.

Link to this function

root_mod(repo_mod)

Link to this function

root_mod_name(repo_mod)

Link to this function

seeds_path(repo)
seeds_path(Ecto.Repo.t()) :: String.t()

Gets the seeds path from a repository.