phil_columns v1.0.1 PhilColumns.Seeder
Summary
Functions
Apply seeds in a directory to a repository with given strategy
Gets all migrated versions
Returns an array of tuples as the seed status of the given repo, without actually running any seeds
Functions
Apply seeds in a directory to a repository with given strategy.
A strategy must be given as an option.
Options
:all- runs all available iftrue:step- runs the specific number of seeds:to- runs all until the supplied version is reached:log- the level to use for logging. Defaults to:info. Can be any ofLogger.level/0values orfalse.
Gets all migrated versions.
This function ensures the migration table exists if no table has been defined yet.